@@ -3,7 +3,7 @@ def viz_json(net, dendro=True, links=False):
   from . import calc_clust
   import numpy as np
 
-  all_dist = calc_clust.group_cutoffs()
+  # all_dist = calc_clust.group_cutoffs()
 
   # linkage information
   net.viz['linkage'] = {}
@@ -57,14 +57,6 @@ def viz_json(net, dendro=True, links=False):
       if len(net.dat['node_info'][inst_rc]['info']) > 0:
         inst_dict['info'] = net.dat['node_info'][inst_rc]['info'][i]
 
-      if dendro is True:
-        inst_dict['group'] = []
-        for tmp_dist in all_dist:
-          tmp_dist = str(tmp_dist).replace('.', '')
-          tmp_append = float(
-              net.dat['node_info'][inst_rc]['group'][tmp_dist][i])
-          inst_dict['group'].append(tmp_append)
-
       net.viz[inst_rc + '_nodes'].append(inst_dict)
 
   mat_types = ['mat', 'mat_orig', 'mat_info', 'mat_hl', 'mat_up', 'mat_dn']
